==> cohesity_management_sdk-1.1.7.tar.gz: cohesity_management_sdk-1.1.7/cohesity_management_sdk/models/upgradability_agent_deployment_status_response_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class UpgradabilityAgentDeploymentStatusResponseEnum(object):

    """Implementation of the 'Upgradability_AgentDeploymentStatusResponse' enum.

    Specfies the upgradability of the agent running on the server.
    Specifies the upgradability of the agent running on the physical server.
    'kUpgradable' indicates the Agent can be upgraded to the agent software
    version on the cluster.
    'kCurrent' indicates the Agent is running the latest version.
    'kUnknown' indicates the Agent's version is not known.
    'kNonUpgradableInvalidVersion' indicates the Agent's version is invalid.
    'kNonUpgradableAgentIsNewer' indicates the Agent's version is newer than
    the agent software version the cluster.
    'kNonUpgradableAgentIsOld' indicates the Agent's version is too old that
    does not support upgrades.

    Attributes:
        KUPGRADABLE: TODO: type description here.
        KCURRENT: TODO: type description here.
        KUNKNOWN: TODO: type description here.
        KNONUPGRADABLEINVALIDVERSION: TODO: type description here.
        KNONUPGRADABLEAGENTISNEWER: TODO: type description here.
        KNONUPGRADABLEAGENTISOLD: TODO: type description here.

    """

    KUPGRADABLE = 'kUpgradable'

    KCURRENT = 'kCurrent'

    KUNKNOWN = 'kUnknown'

    KNONUPGRADABLEINVALIDVERSION = 'kNonUpgradableInvalidVersion'

    KNONUPGRADABLEAGENTISNEWER = 'kNonUpgradableAgentIsNewer'

    KNONUPGRADABLEAGENTISOLD = 'kNonUpgradableAgentIsOld'

==> cohesity_management_sdk-1.5.0.tar.gz: cohesity_management_sdk-1.5.0/cohesity_management_sdk/models/upgradability_agent_deployment_status_response_enum.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Cohesity Inc.

class UpgradabilityAgentDeploymentStatusResponseEnum(object):

    """Implementation of the 'Upgradability_AgentDeploymentStatusResponse' enum.

    Specifies the upgradability of the agent running on the server.
    Specifies the upgradability of the agent running on the physical server.
    'kUpgradable' indicates the Agent can be upgraded to the agent software
    version on the cluster.
    'kCurrent' indicates the Agent is running the latest version.
    'kUnknown' indicates the Agent's version is not known.
    'kNonUpgradableInvalidVersion' indicates the Agent's version is invalid.
    'kNonUpgradableAgentIsNewer' indicates the Agent's version is newer than
    the agent software version the cluster.
    'kNonUpgradableAgentIsOld' indicates the Agent's version is too old that
    does not support upgrades.

    Attributes:
        KUPGRADABLE: TODO: type description here.
        KCURRENT: TODO: type description here.
        KUNKNOWN: TODO: type description here.
        KNONUPGRADABLEINVALIDVERSION: TODO: type description here.
        KNONUPGRADABLEAGENTISNEWER: TODO: type description here.
        KNONUPGRADABLEAGENTISOLD: TODO: type description here.

    """

    KUPGRADABLE = 'kUpgradable'

    KCURRENT = 'kCurrent'

    KUNKNOWN = 'kUnknown'

    KNONUPGRADABLEINVALIDVERSION = 'kNonUpgradableInvalidVersion'

    KNONUPGRADABLEAGENTISNEWER = 'kNonUpgradableAgentIsNewer'

    KNONUPGRADABLEAGENTISOLD = 'kNonUpgradableAgentIsOld'
